turbofeeds.widgets.FeedLinksDesc

Package turbofeeds :: Module widgets :: Class FeedLinksDesc |
[hide private]

# Class FeedLinksDesc

source code

                            object --+
                                     |
        turbogears.widgets.base.Widget --+
                                         |
    turbogears.widgets.base.CompoundWidget --+
                                             |
     turbogears.widgets.base.WidgetDescription --+
                                                 |
                                                FeedLinksDesc

Nested Classes | [hide private]
| template_c
Inherited from `turbogears.widgets.base.WidgetDescription`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `turbogears.widgets.base.WidgetDescription`: `retrieve_css`, `retrieve_javascript` Inherited from `turbogears.widgets.base.WidgetDescription` (private): `_get_description`, `_get_full_class_name`, `_get_name`, `_get_source`, `_get_widget_class` Inherited from `turbogears.widgets.base.CompoundWidget`: `__init__`, `display`, `iter_member_widgets`, `params_for`, `update_params`, `value_for` Inherited from `turbogears.widgets.base.Widget`: `__call__`, `__repr__`, `__setattr__`, `adjust_value`, `render`, `update_data` Inherited from `turbogears.widgets.base.Widget` (private): `_get_is_named` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__str__`

Class Variables | [hide private]
| name = ``'``Feed link list``'``
| for_widget = `FeedLinks(name='widget', feed_types=[('rss2_0', '`...``
| template = ``'``\n <div>\n ${for_widget("Subscribe to %(``...``
Inherited from `turbogears.widgets.base.WidgetDescription`: `member_widgets`, `show_separately` Inherited from `turbogears.widgets.base.CompoundWidget`: `compound` Inherited from `turbogears.widgets.base.Widget`: `css`, `default`, `javascript`, `params`, `params_doc`, `template_vars` Inherited from `turbogears.widgets.base.Widget` (private): `_locked`

Properties | [hide private]
Inherited from `turbogears.widgets.base.WidgetDescription`: `description`, `for_widget_class`, `full_class_name`, `source` Inherited from `turbogears.widgets.base.Widget`: `is_named` Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### for_widget Value:
      FeedLinks(name='widget', feed_types=[('rss2_0', 'RSS 2.0'), ('atom0_3'
      , 'Atom 0.3'), ('atom1_0', 'Atom 1.0')], controller=None, base_url='/f
      eed', url_params={}, title='')

  ### template Value:
      '''
          <div>
              ${for_widget("Subscribe to %(type)s feed",
                title="Click link to access the feed in %(type)s format")}
          </div>
          '''